@@ -2,6 +2,7 @@ use crate::extra;
 use crate::traits::*;
 use itertools::Itertools;
 use nix::unistd;
+use std::ffi::CString;
 use byte_unit::AdjustedByte;
 use regex::Regex;
 use std::fs;
@@ -297,7 +298,26 @@ impl GeneralReadout for NetBSDGeneralReadout {
     }
     
     fn disk_space(&self) -> Result<(AdjustedByte, AdjustedByte), ReadoutError> {
-        crate::shared::disk_space(String::from("/"))
+        let mut s: std::mem::MaybeUninit<libc::statvfs> = std::mem::MaybeUninit::uninit();
+        let path = CString::new("/").expect("Could not create C string for disk usage path.");
+    
+        if unsafe { libc::statvfs(path.as_ptr(), s.as_mut_ptr()) } == 0 {
+            let stats: libc::statvfs = unsafe { s.assume_init() };
+    
+            let disk_size = stats.f_blocks * stats.f_bsize as u64;
+            let free = stats.f_bavail * stats.f_bsize as u64;
+    
+            let used_byte =
+                byte_unit::Byte::from_bytes((disk_size - free) as u128).get_appropriate_unit(true);
+            let disk_size_byte =
+                byte_unit::Byte::from_bytes(disk_size as u128).get_adjusted_unit(used_byte.get_unit());
+    
+            return Ok((used_byte, disk_size_byte));
+        }
+    
+        Err(ReadoutError::Other(String::from(
+            "Error while trying to get statfs structure.",
+        )))
     }
 }
 
